@@ -36,11 +36,10 @@ extern crate core;
 extern crate serde_crate as serde;
 
 mod bigint;
-mod divrem;
 pub mod error;
 #[cfg(feature = "hex")]
 pub mod hex;
-mod posit;
+pub mod posit;
 mod smallint;
 
 pub use bigint::{u256, u512, u1024, i256, i512, i1024};
